summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/religion.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/religion.cc')
-rw-r--r--crawl-ref/source/religion.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index bc6affe8eb..b6b0ac392e 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -3871,8 +3871,9 @@ static bool _destroyed_valuable_weapon(int value, int type)
if (random2(value) >= random2(250))
return (true);
- // Medium valuable items are more likely to net piety at low piety.
- if (random2(value) >= random2(100)
+ // Medium valuable items are more likely to net piety at low piety,
+ // more so for missiles, since they're worth less as single items.
+ if (random2(value) >= random2((type == OBJ_MISSILES) ? 33 : 100)
&& one_chance_in(1 + you.piety / 50))
{
return (true);